@@ -1,7 +1,8 @@
 test_that("pacs::pac_compare_versions", {
   skip_if_offline()
   expect_error(suppressWarnings(pac_compare_versions("memoise", "2.0.0", "22.4.0")))
-  expect_error(pac_compare_versions("memoise", "22.8.0", "22.4.0"))
+  expect_error(pac_compare_versions("memoise", "22.8.0", "22.4.0"), "utils::compareVersion\\(new, old\\) >= 0 is not TRUE")
+  expect_identical(pac_compare_versions("WRONG"), NA)
 })
 
 test_that("pacs::pac_compare_versions online", {
@@ -15,6 +16,7 @@ test_that("pacs::pac_compare_namesapce", {
   skip_if_offline()
   expect_error(suppressWarnings(pac_compare_namespace("memoise", "2.0.0", "22.4.0")))
   expect_error(suppressWarnings(pac_compare_namespace("memoise", "22.8.0", "22.4.0")))
+  expect_identical(pac_compare_namespace("WRONG"), NA)
 })
 
 test_that("pacs::pac_compare_namesapce online", {
@@ -33,3 +35,9 @@ test_that("pacs::pac_compare_namesapce online", {
   ))
   expect_true(suppressWarnings(length(pac_compare_namespace("memoise")) == 10))
 })
+
+test_that("pacs::pac_comapre_namespace offline", {
+  pac_compare_namespace_offline <- pac_compare_namespace
+  mockery::stub(pac_compare_namespace_offline, "is_online", FALSE)
+  expect_error(pac_compare_namespace_offline("memoise", "0.2.1", "2.0.0"), "is_online\\(\\) is not TRUE")
+})
